@@ -1,5 +1,5 @@
-// the gzenv format: json+gzip+base64
-// a quickly designed format to export the whole environment back into itself
+// Package gzenv implements a compressed environment format using json+gzip+base64.
+// It provides a quickly designed format to export the whole environment back into itself.
 package gzenv
 
 import (
@@ -8,6 +8,7 @@ import (
 	"encoding/base64"
 	"encoding/json"
 	"fmt"
+	"log"
 	"io"
 	"strings"
 )
@@ -17,14 +18,16 @@ func Marshal(obj interface{}) string {
 	jsonData, err := json.Marshal(obj)
 
 	if err != nil {
-		panic(fmt.Errorf("marshal(): %v", err))
+		panic(fmt.Errorf("marshal(): %w", err))
 	}
 
 	zlibData := bytes.NewBuffer([]byte{})
 	w := zlib.NewWriter(zlibData)
 	// we assume the zlib writer would never fail
 	_, _ = w.Write(jsonData)
-	w.Close()
+	if err := w.Close(); err != nil {
+		log.Printf("Warning: failed to close zlib writer: %v", err)
+	}
 
 	base64Data := base64.URLEncoding.EncodeToString(zlibData.Bytes())
 
@@ -37,25 +40,29 @@ func Unmarshal(gzenv string, obj interface{}) error {
 
 	data, err := base64.URLEncoding.DecodeString(gzenv)
 	if err != nil {
-		return fmt.Errorf("unmarshal() base64 decoding: %v", err)
+		return fmt.Errorf("unmarshal() base64 decoding: %w", err)
 	}
 
 	zlibReader := bytes.NewReader(data)
 	w, err := zlib.NewReader(zlibReader)
 	if err != nil {
-		return fmt.Errorf("unmarshal() zlib opening: %v", err)
+		return fmt.Errorf("unmarshal() zlib opening: %w", err)
 	}
 
 	envData := bytes.NewBuffer([]byte{})
+	// G110: Potential DoS vulnerability via decompression bomb (gosec)
+	// #nosec
 	_, err = io.Copy(envData, w)
 	if err != nil {
-		return fmt.Errorf("unmarshal() zlib decoding: %v", err)
+		return fmt.Errorf("unmarshal() zlib decoding: %w", err)
+	}
+	if err := w.Close(); err != nil {
+		log.Printf("Warning: failed to close zlib reader: %v", err)
 	}
-	w.Close()
 
 	err = json.Unmarshal(envData.Bytes(), &obj)
 	if err != nil {
-		return fmt.Errorf("unmarshal() json parsing: %v", err)
+		return fmt.Errorf("unmarshal() json parsing: %w", err)
 	}
 
 	return nil
