@@ -11,11 +11,11 @@ var CmdDeny = &Cmd{
 	Name:    "block",
 	Desc:    "Revokes the authorization of a given .envrc or .env file.",
 	Args:    []string{"[PATH_TO_RC]"},
-	Aliases: []string{"deny", "revoke"},
+	Aliases: []string{"deny", "disallow", "revoke"},
 	Action:  actionWithConfig(cmdDenyAction),
 }
 
-func cmdDenyAction(env Env, args []string, config *Config) (err error) {
+func cmdDenyAction(_ Env, args []string, config *Config) (err error) {
 	var rcPath string
 
 	if len(args) > 1 {
