@@ -2,16 +2,15 @@ package cmd
 
 import (
 	"fmt"
-	"io/ioutil"
-
 	"github.com/direnv/direnv/v2/pkg/dotenv"
+	"os"
+	"path/filepath"
 )
 
 // CmdDotEnv is `direnv dotenv [SHELL [PATH_TO_DOTENV]]`
 // Transforms a .env file to evaluatable `export KEY=PAIR` statements.
 //
-// See: https://github.com/bkeepers/dotenv and
-//   https://github.com/ddollar/foreman
+// See: https://github.com/bkeepers/dotenv and https://github.com/ddollar/foreman
 var CmdDotEnv = &Cmd{
 	Name:    "dotenv",
 	Desc:    "Transforms a .env file to evaluatable `export KEY=PAIR` statements",
@@ -20,7 +19,7 @@ var CmdDotEnv = &Cmd{
 	Action:  actionSimple(cmdDotEnvAction),
 }
 
-func cmdDotEnvAction(env Env, args []string) (err error) {
+func cmdDotEnvAction(_ Env, args []string) (err error) {
 	var shell Shell
 	var newenv Env
 	var target string
@@ -40,16 +39,31 @@ func cmdDotEnvAction(env Env, args []string) (err error) {
 	}
 
 	var data []byte
-	if data, err = ioutil.ReadFile(target); err != nil {
+	if data, err = os.ReadFile(target); err != nil {
 		return
 	}
 
+	// Set PWD env var to the directory the .env file resides in. This results
+	// in the least amount of surprise, as a dotenv file is most often defined
+	// in the same directory it's loaded from, so referring to PWD should match
+	// the directory of the .env file.
+	path, err := filepath.Abs(target)
+	if err != nil {
+		return err
+	}
+	if err := os.Setenv("PWD", filepath.Dir(path)); err != nil {
+		return err
+	}
+
 	newenv, err = dotenv.Parse(string(data))
 	if err != nil {
 		return err
 	}
 
-	str := newenv.ToShell(shell)
+	str, err := newenv.ToShell(shell)
+	if err != nil {
+		return err
+	}
 	fmt.Println(str)
 
 	return
