@@ -21,7 +21,7 @@ var CmdHook = &Cmd{
 	Action: actionSimple(cmdHookAction),
 }
 
-func cmdHookAction(env Env, args []string) (err error) {
+func cmdHookAction(_ Env, args []string) (err error) {
 	var target string
 
 	if len(args) > 1 {
@@ -34,7 +34,7 @@ func cmdHookAction(env Env, args []string) (err error) {
 	}
 
 	// Convert Windows path if needed
-	selfPath = strings.Replace(selfPath, "\\", "/", -1)
+	selfPath = strings.ReplaceAll(selfPath, "\\", "/")
 	ctx := HookContext{selfPath}
 
 	shell := DetectShell(target)
