@@ -8,7 +8,7 @@ import (
 var CmdStdlib = &Cmd{
 	Name: "stdlib",
 	Desc: "Displays the stdlib available in the .envrc execution context",
-	Action: actionWithConfig(func(env Env, args []string, config *Config) error {
+	Action: actionWithConfig(func(_ Env, _ []string, config *Config) error {
 		fmt.Println(getStdlib(config))
 		return nil
 	}),
