@@ -55,7 +55,11 @@ func watchDirCommand(env Env, args []string) (err error) {
 	e := make(ShellExport)
 	e.Add(DIRENV_WATCHES, watches.Marshal())
 
-	os.Stdout.WriteString(shell.Export(e))
+	exportStr, err := shell.Export(e)
+	if err != nil {
+		return err
+	}
+	_, _ = os.Stdout.WriteString(exportStr)
 
 	return
 }
