@@ -15,10 +15,10 @@ func (s gzenvShell) Hook() (string, error) {
 	return "", errors.New("the gzenv shell doesn't support hooking")
 }
 
-func (s gzenvShell) Export(e ShellExport) string {
-	return gzenv.Marshal(e)
+func (s gzenvShell) Export(e ShellExport) (string, error) {
+	return gzenv.Marshal(e), nil
 }
 
-func (s gzenvShell) Dump(env Env) string {
-	return gzenv.Marshal(env)
+func (s gzenvShell) Dump(env Env) (string, error) {
+	return gzenv.Marshal(env), nil
 }
