@@ -8,17 +8,17 @@ var Zsh Shell = zsh{}
 
 const zshHook = `
 _direnv_hook() {
-  trap -- '' SIGINT;
-  eval "$("{{.SelfPath}}" export zsh)";
-  trap - SIGINT;
+  trap -- '' SIGINT
+  eval "$("{{.SelfPath}}" export zsh)"
+  trap - SIGINT
 }
-typeset -ag precmd_functions;
-if [[ -z "${precmd_functions[(r)_direnv_hook]+1}" ]]; then
-  precmd_functions=( _direnv_hook ${precmd_functions[@]} )
+typeset -ag precmd_functions
+if (( ! ${precmd_functions[(I)_direnv_hook]} )); then
+  precmd_functions=(_direnv_hook $precmd_functions)
 fi
-typeset -ag chpwd_functions;
-if [[ -z "${chpwd_functions[(r)_direnv_hook]+1}" ]]; then
-  chpwd_functions=( _direnv_hook ${chpwd_functions[@]} )
+typeset -ag chpwd_functions
+if (( ! ${chpwd_functions[(I)_direnv_hook]} )); then
+  chpwd_functions=(_direnv_hook $chpwd_functions)
 fi
 `
 
@@ -26,7 +26,8 @@ func (sh zsh) Hook() (string, error) {
 	return zshHook, nil
 }
 
-func (sh zsh) Export(e ShellExport) (out string) {
+func (sh zsh) Export(e ShellExport) (string, error) {
+	var out string
 	for key, value := range e {
 		if value == nil {
 			out += sh.unset(key)
@@ -34,14 +35,15 @@ func (sh zsh) Export(e ShellExport) (out string) {
 			out += sh.export(key, *value)
 		}
 	}
-	return out
+	return out, nil
 }
 
-func (sh zsh) Dump(env Env) (out string) {
+func (sh zsh) Dump(env Env) (string, error) {
+	var out string
 	for key, value := range env {
 		out += sh.export(key, value)
 	}
-	return out
+	return out, nil
 }
 
 func (sh zsh) export(key, value string) string {
